(function($){
	$.fn.extend({
		posterGallery: function(options) {
			var defaults = {
				transitionSpeed: 2,
				galleryHeight: 300,
				galleryWidth: 800,
				galleryBackground: '#eee4c6',
				outerShadow: '0 0 3px 0 #999',
			}
			var options =  $.extend(defaults, options);
			return this.each(function() {
				/*Seting up some variables*/
				var house = $(this);
				var speed = options.transitionSpeed*1000;
				var imgHeight = options.galleryHeight*0.8;
				var canvasPadding = options.galleryHeight*0.1;
				var imgBorder = canvasPadding;

				/*Adding styles to parent container and li elements*/
				$(house).css({overflow: 'hidden', width: options.galleryWidth, position: 'relative', 'background-color': options.galleryBackground, height: imgHeight+canvasPadding*2, 'border-bottom': '1px solid #999', 'box-shadow': options.outerShadow, 'border-radius': '2px',});
				$("li", house).css({float: 'left', 'margin': '0 '+imgBorder+'px'});
				
				/*Calculation of stage width*/
				/*Getting width of the movable stage by adding up the width and margins of all scalled images.
				Images will be scalled as follows: 
				The height of a portrait image takes 80% of the gallery height (if the gallery has a height of 300px the image height will be 260px). 
				If the image is wider than tall (landscape format) the 260px from my example will be used to set the image width.*/
				var amountOfImg = $("img", house).size();
				var i = 0;
				var widthOfUl = 0;
				while(i < amountOfImg) {
					var realImgHeight = $("img:eq("+i+")", house).height();	
					var imgHeightFactor = realImgHeight/imgHeight;
					var realImgWidth = $("li:eq("+i+")", house).width();
					if (realImgHeight > realImgWidth) {
						$("img:eq("+i+")", house).height(imgHeight);
						$("img:eq("+i+")", house).css({'margin-top': canvasPadding});
						var checkwidth1 = $("li:eq("+i+")", house).width();
						var widthOfUl = widthOfUl+checkwidth1+imgBorder*2;
					}	else {
						$("img:eq("+i+")", house).width(imgHeight);
						var scaledImgHeight = $("img:eq("+i+")", house).height();
						var imagePadding = options.galleryHeight-scaledImgHeight;
						imagePadding = imagePadding/2;
						$("img:eq("+i+")", house).css({'margin-top': imagePadding});
						var checkwidth2 = $("li:eq("+i+")", house).width();
						var widthOfUl = widthOfUl+checkwidth2+imgBorder*2
					}
					i++;
				}
				widthOfUl = Math.round(widthOfUl)+1;
				
				/*Adding styles/attributes to img and ul*/
				$("img", house).css({'box-shadow': options.outerShadow});
				$("ul", house).width(widthOfUl).css({position: 'relative', width: widthOfUl, 'z-index': '1', left: '0', top: '0'});
				
				/*Injecting the trigger buttons*/
				$(house).append('<div class="trigger left"><span></span></div><div class="trigger right"><span></span></div>');
				/*Setting position of the arrows depending on the gallery height*/
				var arrowHeight = $(".trigger span", house).height();
				var spriteMargin = options.galleryHeight-arrowHeight
				spriteMargin = spriteMargin/2;
				$(".trigger span", house).css({'margin-top': spriteMargin});
				/*Hiding the trigger buttons*/
				$(".trigger", house).hide();
				
				/*Animation*/
				/*Using jQuery's .animate method to get a smooth movement from left to right.
				One feature of Postergallery is that you can stop/start the animation at any position whilst keeping a constant velocity.
				To make this work we got to calculate the animation time (var restTime) by 
				setting the start/stop point (var currentPosition) into proportion to our stage width (var limit).
				By taking the same proportion of the initial speed (var speed = x ms) we get the actual animation time (var restTime).*/
				var limit = widthOfUl-options.galleryWidth;
				$(".trigger.right", house).hover(function() {
					var currentPosition = -parseFloat($("ul", house).css('left'))+1;
					var proportion = currentPosition/limit;
					var restTime = speed-speed*proportion;
					$("ul", house).stop().animate({left: '-'+limit+''}, restTime);
				}, function() {
					var currentPosition = parseFloat($("ul", house).css('left'));
					$("ul", house).stop().animate({ left: currentPosition+'px' });
				});
				var limit = widthOfUl-options.galleryWidth;
				$(".trigger.left", house).hover(function() {
					var currentPosition = -parseFloat($("ul", house).css('left'));
					var proportion = 1-currentPosition/limit;
					var restTime = speed-speed*proportion;
					$("ul", house).stop().animate({left: "+0"}, restTime);
				}, function() {
					var currentPosition = parseFloat($("ul", house).css('left'));
					$("ul", house).stop().animate({ left: currentPosition+'px' });
				});

				/*Setting up the mechanism to fadi in/out the trigger buttons by hovering over the gallery container*/
				$(house).hover(function () {
					$(".trigger", house).fadeTo(150, 0.76);
				}, function() {
					$(".trigger", house).fadeOut(150);
				});
			});
		}
	});
})(jQuery);